@@ -323,6 +323,8 @@ def start(build_type, flutter, minimal_ios_version, app_version, build_number, n
 
         if status in ["config", "succeeded"]:
             console.print(Text.from_markup(f"Your build has succeeded"))
+            if build_type == "publication":
+                console.print("It will appear on your appstoreconnect account shortly")
             if status == "config":
                 connect({build_instance['key']})
             return
@@ -476,7 +478,7 @@ def connect(key, yes):
             auth_info = Panel(Text.from_markup(
                 textwrap.dedent(
                     f"""
-                        url: [bold]spice://appollo.deuse.dev:{build_instance["remote_desktop_port"]}[/bold]
+                        url: [bold]spice://appollo.space:{build_instance["remote_desktop_port"]}[/bold]
                         connection_password: [bold]{build_instance["remote_desktop_password"]}[/bold]
                         user: [bold]appollo[/bold]
                         user_password: [bold]{build_instance["vm_password"]}[/bold]
@@ -540,6 +542,7 @@ def patch(key, output="appollo.patch"):
             f.write(response)
     else:
         console.print("This build does not have any patch")
+        return
 
     code = Syntax("git am appollo.patch", lexer="shell")
     console.print("To apply a patch, run")
@@ -611,9 +614,13 @@ def build_name(build_instance):
     """ Based on a build instance returns a user friendly name for the build. """
     from datetime import datetime
 
-    build_instance['start_time'] = build_instance['start_time'][:-3]+build_instance['start_time'][-2:]  # Remove timezone ':' otherwise it can't parse
-    start_time = datetime.strptime(build_instance['start_time'], "%Y-%m-%dT%H:%M:%S.%f%z")
-    start_time_str = start_time.strftime('%Y-%m-%d %H:%M')
+    if "start_time" in build_instance and build_instance["start_time"]:
+        build_instance['start_time'] = build_instance['start_time'][:-3]+build_instance['start_time'][-2:]  # Remove timezone ':' otherwise it can't parse
+        start_time = datetime.strptime(build_instance['start_time'], "%Y-%m-%dT%H:%M:%S.%f%z")
+        start_time_str = start_time.strftime('%Y-%m-%d %H:%M')
+    else:
+        start_time_str = "Not started"
+
     # TODO check if timezones are respected.
     return f"{build_instance['application']} - {build_instance['name']} - {start_time_str}"
 
